// ptp_hotspot_click
//RDS Worldmap System
//Montgomery Markland -- Nov 1, 2006
//A simple worldmap system designed for use in situations when the world map hotspots are all available (Beta Testing Purgatorio)
//on first-look
//Adapted code from OEI kinc_worldmap

#include "ginc_transition"
#include "ginc_debug"

// ** world map locout functions **

// multiple PCs simultaneously clicking travel on the world map causes problems. We use a cooldown time to preven this.
void SetWorldMapLocked();
int GetWorldMapLocked();


/////////////////////////
// CONSTANT DECLARATIONS
/////////////////////////

// GENERAL //

// these are for locking the world map so only one user can use it at a time
const string WORLD_MAP_LOCKED = "00_bWorldMapLocked";
const string WORLD_MAP_LOCKER = "oWorldMapLocker";
const int STRING_REF_MAP_LOCKED = 183512;
const string WORLD_MAP_LOCKED_DAY = "00_nWorldMapLockDay";
const string WORLD_MAP_LOCKED_HOUR = "00_nWorldMapLockHour";
const string WORLD_MAP_LOCKED_MINUTE = "00_nWorldMapLockMinute";
const string WORLD_MAP_LOCKED_SECOND = "00_nWorldMapLockSecond";
const int WORLD_MAP_LOCK_COOLDOWN = 18; //seconds until we allow another click
const string WORLD_MAP_LOCK_INITIALIZED = "00_bWorldMapLockInit";

void SetWorldMapLocked()
{
SetGlobalInt(WORLD_MAP_LOCKED_DAY, GetCalendarDay());
SetGlobalInt(WORLD_MAP_LOCKED_HOUR, GetTimeHour());
SetGlobalInt(WORLD_MAP_LOCKED_MINUTE, GetTimeMinute());
SetGlobalInt(WORLD_MAP_LOCKED_SECOND, GetTimeSecond());

SetGlobalInt(WORLD_MAP_LOCK_INITIALIZED, TRUE); //so we know the timer is initialized

PrettyMessage("World map locked at time " + IntToString(GetTimeHour()) + ":" + IntToString(GetTimeMinute()) + ":" + IntToString(GetTimeSecond()));
}

int TimeToSeconds(int nHour, int nMinute, int nSecond)
{
//for ease, we just convert the time into seconds -- 60 for 60 seconds in a minute, 3600 for number of seconds in an hour.
return nSecond + nMinute * 60 + nHour * 3600;
}

int GetWorldMapLocked()
{
if(GetIsSinglePlayer())
{
return FALSE;
}

if(!GetGlobalInt(WORLD_MAP_LOCK_INITIALIZED))
{
return FALSE;
}

int nLockedHour = GetGlobalInt(WORLD_MAP_LOCKED_HOUR);
int nLockedMinute = GetGlobalInt(WORLD_MAP_LOCKED_MINUTE);
int nLockedSecond = GetGlobalInt(WORLD_MAP_LOCKED_SECOND);

int nCurrentHour = GetTimeHour();
int nCurrentMinute = GetTimeMinute();
int nCurrentSecond = GetTimeSecond();

int nTotalLockedSeconds = TimeToSeconds(nLockedHour,nLockedMinute,nLockedSecond);
int nTargetTime = nTotalLockedSeconds + WORLD_MAP_LOCK_COOLDOWN; //10 sec cooldown

int nCurrentSeconds = TimeToSeconds(nCurrentHour,nCurrentMinute,nCurrentSecond);

// PrettyDebug("Target time for unlock = " + IntToString(nTargetTime));
// PrettyDebug("Current time in seconds = " + IntToString(nCurrentSeconds));

//same day
if(nTargetTime < nCurrentSeconds)
{
// PrettyDebug(IntToString(nCurrentSeconds - nTotalLockedSeconds) + " seconds passed since the last transition.");
return FALSE;
}

//we've rolled to the next calendar day
int nLockedDay = GetGlobalInt(WORLD_MAP_LOCKED_DAY);
int nCurrentDay = GetCalendarDay();

//!= is the check here because the day change could roll the month
//so going from month 1 day 28 to month 2 day 0 should still register as a day having passed.
if(nCurrentDay != nLockedDay && nCurrentSeconds > WORLD_MAP_LOCK_COOLDOWN)
{
return FALSE;
}

return TRUE;
}

void main(string sHotspot)

{
//Get the player's compass heading from the previous area
string sCompass = GetLocalString(OBJECT_SELF, "temp_wm_compass");
DeleteLocalString(OBJECT_SELF, "temp_wm_compass");
//Combine the player's compass heading with the hotspot string (targets proper waypoint in target area)
string sDestination = sHotspot + sCompass;
//Rather than increasing code complexity, we simple assume the existence of all
//Four compass-heading waypoints in the target area.
//This just means that the builder should paint all four compass heading waypoints
//(sHotspot+_n, sHotspot+_s, sHotspot+_e, sHotspot_+w) in the target area for a particular hotspot
//If there aren't four compass headings into the area, paint multiple waypoints for a specific compass heading
//IE, if you only have 3 compass heading entrances, _n, _s, _e - then paint "_w" in the same place as
//_n or _s. This system gives the builder flexibility to choose defaults and multiple defaults
object oDestination = GetObjectByTag(sDestination);
object oPC = OBJECT_SELF;
//critPathEncounter, nonCritPathEncounter and randomEncounter code to be added later
if(!GetIsSinglePlayer())
{
if(GetWorldMapLocked())
{
SendMessageToPC(oPC, GetStringByStrRef(STRING_REF_MAP_LOCKED));
return;
}
else
{
SetWorldMapLocked();
}
}
SinglePartyTransition(oPC, oDestination);
}